.. include:: readme.rst

.. toctree::
   :hidden:
   :maxdepth: 2

   Overview <readme>

.. toctree::
   :caption: Tutorials
   :hidden:

   tutorials/01_GreenGuard_Quickstart
   tutorials/02_Extract_Readings

.. toctree::
   :caption: Advanced Usage
   :hidden:

   advanced_usage/concepts
   advanced_usage/csv
   advanced_usage/docker

.. toctree::
   :caption: Resources
   :hidden:

   API Reference <api/greenguard>
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
